Noether Dataset Zoo
===================

In the `Noether Dataset Zoo <https://github.com/Emmi-AI/noether/tree/main/src/noether/data/datasets>`_ we currently provide the following datasets:

.. list-table::
   :header-rows: 1
   :widths: 20 20 30 30

   * - Dataset
     - Type
     - Class Path
     - Data processing README
   * - **ShapeNet-Car**
     - CFD Aerodynamics
     - `noether.data.datasets.cfd.ShapeNetCarDataset <https://github.com/Emmi-AI/noether/tree/main/src/noether/data/datasets/cfd/shapenet_car/dataset.py>`_
     - `README.MD <https://github.com/Emmi-AI/noether/tree/main/src/noether/data/datasets/cfd/shapenet_car/README.MD>`_
   * - **AhmedML**
     - CFD Aerodynamics
     - `noether.data.datasets.cfd.AhmedMLDataset <https://github.com/Emmi-AI/noether/tree/main/src/noether/data/datasets/cfd/caeml/ahmedml/dataset.py>`_
     - `README.MD <https://github.com/Emmi-AI/noether/tree/main/src/noether/data/datasets/cfd/caeml/README.MD>`_
   * - **DrivAerML**
     - CFD Aerodynamics
     - `noether.data.datasets.cfd.DrivAerMLDataset <https://github.com/Emmi-AI/noether/tree/main/src/noether/data/datasets/cfd/caeml/drivaerml/dataset.py>`_
     - `README.MD <https://github.com/Emmi-AI/noether/tree/main/src/noether/data/datasets/cfd/caeml/README.MD>`_
   * - **DrivAerNet++**
     - CFD Aerodynamics
     - `noether.data.datasets.cfd.DrivAerNetDataset <https://github.com/Emmi-AI/noether/tree/main/src/noether/data/datasets/cfd/drivaernet/dataset.py>`_
     - `README.MD <https://github.com/Emmi-AI/noether/tree/main/src/noether/data/datasets/cfd/drivaernet/README.MD>`_
   * - **Wing Dataset**
     - CFD Aerodynamics
     - `noether.data.datasets.cfd.EmmiWingDataset <https://github.com/Emmi-AI/noether/tree/main/src/noether/data/datasets/cfd/caeml/ahmedml/dataset.py>`_
     - `README.MD <https://github.com/Emmi-AI/noether/tree/main/src/noether/data/datasets/cfd/emmi_wing/README.MD>`_